package svc

import (
	"applet/app/admin/md"
	"applet/app/db"
	"applet/app/db/model"
	"errors"
	"time"
)

func AddCentralKitchenForSchoolPackage(req md.SaveCentralKitchenForSchoolPackageReq) (err error) {
	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()
	now := time.Now()
	//TODO::判断当前月份是否存在
	centralKitchenForSchoolPackageDb := db.CentralKitchenForSchoolPackageDb{}
	centralKitchenForSchoolPackageDb.Set()
	isHasPackage, err := centralKitchenForSchoolPackageDb.GetCentralKitchenForSchoolPackageByMonth(req.EnterpriseId, req.Year, req.Month)
	if err != nil {
		return err
	}
	if isHasPackage != nil {
		return errors.New("请勿重复添加【" + req.Month + "】套餐")
	}

	////1、查询`central_kitchen_for_school_with_spec`
	//centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	//centralKitchenForSchoolWithSpec.Set(req.EnterpriseId)
	//spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	//if err != nil {
	//	_ = session.Rollback()
	//	return err
	//}
	//1、新增`central_kitchen_for_school_package`
	packageId, err := centralKitchenForSchoolPackageDb.CentralKitchenForSchoolPackageInsertBySession(session, &model.CentralKitchenForSchoolPackage{
		EnterpriseId: req.EnterpriseId,
		Year:         req.Year,
		Month:        req.Month,
		TotalPrice:   "0",
		StartDate:    req.StartDate,
		EndDate:      req.EndDate,
		State:        1,
		CreateAt:     now.Format("2006-01-02 15:04:05"),
		UpdateAt:     now.Format("2006-01-02 15:04:05"),
	})
	if err != nil {
		_ = session.Rollback()
		return err
	}

	//2、批量新增 `central_kitchen_for_school_package_with_day`
	var centralKitchenForSchoolPackageWithDays []*model.CentralKitchenForSchoolPackageWithDay
	for _, v := range req.DateList {
		var isOpenBreakfast, isOpenLunch, isOpenDinner, isOpenReplenish = md.CloseBreakfast, md.CloseLunch, md.CloseDinner, md.CloseReplenish
		if v.IsOpenBreakfast == md.OpenBreakfast {
			isOpenBreakfast = md.OpenBreakfast
		}
		if v.IsOpenLunch == md.OpenLunch {
			isOpenLunch = md.OpenLunch
		}
		if v.IsOpenDinner == md.OpenDinner {
			isOpenDinner = md.OpenDinner
		}
		if v.IsOpenReplenish == md.OpenReplenish {
			isOpenReplenish = md.OpenReplenish
		}
		centralKitchenForSchoolPackageWithDays = append(centralKitchenForSchoolPackageWithDays, &model.CentralKitchenForSchoolPackageWithDay{
			Date:            v.Date,
			PackageId:       packageId,
			IsOpenBreakfast: isOpenBreakfast,
			IsOpenLunch:     isOpenLunch,
			IsOpenDinner:    isOpenDinner,
			IsOpenReplenish: isOpenReplenish,
		})
	}
	centralKitchenForSchoolPackageWithDayDb := db.CentralKitchenForSchoolPackageWithDayDb{}
	centralKitchenForSchoolPackageWithDayDb.Set(packageId)
	_, err = centralKitchenForSchoolPackageWithDayDb.BatchAddCentralKitchenForSchoolPackageWithDaysBySession(session, centralKitchenForSchoolPackageWithDays)
	if err != nil {
		_ = session.Rollback()
		return err
	}
	return session.Commit()
}

func UpdateCentralKitchenForSchoolPackage(req md.SaveCentralKitchenForSchoolPackageReq) (err error) {
	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()
	now := time.Now()
	////1、查询`central_kitchen_for_school_with_spec`
	//centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	//centralKitchenForSchoolWithSpec.Set(req.EnterpriseId)
	//spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	//if err != nil {
	//	_ = session.Rollback()
	//	return err
	//}
	//2、修改`central_kitchen_for_school_package`
	centralKitchenForSchoolPackageDb := db.CentralKitchenForSchoolPackageDb{}
	centralKitchenForSchoolPackageDb.Set()
	centralKitchenForSchoolPackage, err := centralKitchenForSchoolPackageDb.GetCentralKitchenForSchoolPackage(req.PackageId)
	if err != nil {
		_ = session.Rollback()
		return err
	}
	if centralKitchenForSchoolPackage == nil {
		_ = session.Rollback()
		return errors.New("未查询到对应套餐记录")
	}
	centralKitchenForSchoolPackage.Year = req.Year
	centralKitchenForSchoolPackage.Month = req.Month
	centralKitchenForSchoolPackage.StartDate = req.StartDate
	centralKitchenForSchoolPackage.EndDate = req.EndDate
	centralKitchenForSchoolPackage.State = req.State
	centralKitchenForSchoolPackage.UpdateAt = now.Format("2006-01-02 15:04:05")
	affected, err := centralKitchenForSchoolPackageDb.CentralKitchenForSchoolPackageUpdateBySession(session, centralKitchenForSchoolPackage.Id, centralKitchenForSchoolPackage)
	if err != nil {
		_ = session.Rollback()
		return
	}
	if affected == 0 {
		_ = session.Rollback()
		return errors.New("更新套餐记录失败")
	}

	//3、删除 `central_kitchen_for_school_package_with_day` 旧数据
	centralKitchenForSchoolPackageWithDayDb := db.CentralKitchenForSchoolPackageWithDayDb{}
	centralKitchenForSchoolPackageWithDayDb.Set(centralKitchenForSchoolPackage.Id)
	_, err = centralKitchenForSchoolPackageWithDayDb.CentralKitchenForSchoolPackageWithDayDeleteBySession(session)
	if err != nil {
		_ = session.Rollback()
		return
	}

	//4、批量新增 `central_kitchen_for_school_package_with_day`
	var centralKitchenForSchoolPackageWithDays []*model.CentralKitchenForSchoolPackageWithDay
	for _, v := range req.DateList {
		var isOpenBreakfast, isOpenLunch, isOpenDinner, isOpenReplenish = md.CloseBreakfast, md.CloseLunch, md.CloseDinner, md.CloseReplenish
		if v.IsOpenBreakfast == md.OpenBreakfast {
			isOpenBreakfast = md.OpenBreakfast
		}
		if v.IsOpenLunch == md.OpenLunch {
			isOpenLunch = md.OpenLunch
		}
		if v.IsOpenDinner == md.OpenDinner {
			isOpenDinner = md.OpenDinner
		}
		if v.IsOpenReplenish == md.OpenReplenish {
			isOpenReplenish = md.OpenReplenish
		}
		centralKitchenForSchoolPackageWithDays = append(centralKitchenForSchoolPackageWithDays, &model.CentralKitchenForSchoolPackageWithDay{
			Date:            v.Date,
			PackageId:       centralKitchenForSchoolPackage.Id,
			IsOpenBreakfast: isOpenBreakfast,
			IsOpenLunch:     isOpenLunch,
			IsOpenDinner:    isOpenDinner,
			IsOpenReplenish: isOpenReplenish,
		})
	}
	_, err = centralKitchenForSchoolPackageWithDayDb.BatchAddCentralKitchenForSchoolPackageWithDaysBySession(session, centralKitchenForSchoolPackageWithDays)
	if err != nil {
		_ = session.Rollback()
		return err
	}
	return session.Commit()
}

func DeleteCentralKitchenForSchoolPackage(packageId int) (err error) {
	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()
	//1、删除`central_kitchen_for_school_package`
	centralKitchenForSchoolPackageDb := db.CentralKitchenForSchoolPackageDb{}
	centralKitchenForSchoolPackageDb.Set()
	centralKitchenForSchoolPackage, err := centralKitchenForSchoolPackageDb.GetCentralKitchenForSchoolPackage(packageId)
	if err != nil {
		_ = session.Rollback()
		return err
	}
	if centralKitchenForSchoolPackage == nil {
		_ = session.Rollback()
		return errors.New("未查询到对应套餐记录")
	}
	centralKitchenForSchoolPackage.IsDelete = 1
	affected, err := centralKitchenForSchoolPackageDb.CentralKitchenForSchoolPackageUpdateBySession(session, centralKitchenForSchoolPackage.Id, centralKitchenForSchoolPackage, "is_delete")
	if err != nil {
		_ = session.Rollback()
		return
	}
	if affected == 0 {
		_ = session.Rollback()
		return errors.New("删除套餐记录失败")
	}
	return session.Commit()
}
